package com.example.what_the_fantasy.ui.viewModels

import android.util.Log
import androidx.lifecycle.ViewModel
import com.example.what_the_fantasy.data.model.SrcLanguage
import com.example.what_the_fantasy.data.model.User
import com.example.what_the_fantasy.data.services.ServicesAPI
import com.example.what_the_fantasy.data.services.ServicesStub
import com.example.what_the_fantasy.ui.states.CurrentUserState
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.flow.update

class CurrentUserViewModel : ViewModel(){
    //private val services = ServicesStub()
    private val services = ServicesAPI() // faire repository qui gère les services Stub et API
    private val _currentUserState = MutableStateFlow(CurrentUserState())
    var currentUserState : StateFlow<CurrentUserState> = _currentUserState.asStateFlow()


    suspend fun initialiseCurrentUser(index : Int){
        services.getUserById(index).let {
                setId(it.id)
                setUsername(it.username)
                setEmail(it.email)
                setPassword(it.password)
                setLangue(it.langage) // A rajouter quand on aura le langage
                setImage(it.imgUrl)
            }
    }

    fun setUser(user: User) {
        _currentUserState.value = CurrentUserState(
            id = user.id,
            username = user.username,
            email = user.email,
            password = user.password,
            imagePath = user.imgUrl,
        )
    }

    fun clearCurrentUser(){
        _currentUserState.value = CurrentUserState()
    }

    fun setId(id : Int){
        _currentUserState.update {it.copy(id = id)}
    }

    fun setUsername(username : String){
        _currentUserState.update {it.copy(username = username)}
    }

    fun setEmail(email : String){
        _currentUserState.update {it.copy(email = email)}
    }

    fun setPassword(password : String){
        _currentUserState.update {it.copy(password = password)}
    }


    fun setLangue(langue : SrcLanguage){
        _currentUserState.update {it.copy(langage = langue)}
    }
    fun setImage(imagePath : String){
        _currentUserState.update {it.copy(imagePath = imagePath)}
    }




    suspend fun editUsername(username: String, index: Int): Boolean {
        if (!services.EditUsername(username, index, this)) {
            _currentUserState.update {
                it.copy(username = username)
            }
            return true
        }
        return false
    }

    suspend fun editEmail(email : String, index : Int) : Boolean{

        if(!services.EditEmail(email, index, this)){
            _currentUserState.update {
                it.copy(email = email)
            }
            return true
        }
        return false
    }


    suspend fun editPassword(password : String, index : Int){
        services.EditPasswd(password, index, this)

    }

    suspend fun editLangue(index : Int){
        val langage = services.ChangeLangage(index, this)

        _currentUserState.update {
            it.copy(langage = langage)
        }
    }

    suspend fun editImage(index : Int){
//       _currentUserState.update {
//            it.copy(imagePath = services.EditImage(index, this))
//        }
    }
}