package com.example.what_the_fantasy

import org.junit.Assert.assertEquals
import org.junit.Test
import com.example.what_the_fantasy.data.services.IServices
import com.example.what_the_fantasy.data.services.ServicesStub

class UnitTestQuote {
    private val services : IServices = ServicesStub()

    @Test
    fun testGetQuote(){
        val quote = services.getQuote(1)
        assertEquals("All we have to decide is what to do with the time that is given us.",quote?.content)
    }

    @Test
    fun testGetSomeQuote_OK(){
        val quote = services.getSomeQuotes(4,1)
        assertEquals(4,quote.size)
    }

    @Test
    fun testGetSomeQuoteNegatif(){
        val quote = services.getSomeQuotes(-1,1)
        assertEquals(1,quote.size)
    }

    @Test
    fun testGetSomeQuote0(){
        val quote = services.getSomeQuotes(0,1)
        assertEquals(0,quote.size)
    }

    @Test
    fun testSearchByFullQuote(){
        val quote = services.search("contenu","I am no man.",1)
        assertEquals("I am no man.",quote[0].content)
    }

    @Test
    fun testSearchByHalfQuote(){
        val quote = services.search("contenu","I am no",1)
        assertEquals("I am no man.",quote[0].content)
    }

    @Test
    fun testSearchByFullQuoteWithUpperCase(){
        val quote = services.search("contenu","I aM nO MaN",1)
        assertEquals("I am no man.",quote[0].content)
    }

    @Test
    fun testSearchByHalfQuoteWithUpperCase(){
        val quote = services.search("contenu","I aM nO",1)
        assertEquals("I am no man.",quote[0].content)
    }

    @Test
    fun testSearchByFullQuoteBad(){
        val quote = services.search("contenu","I am no Man bad",1)
        assertEquals(0,quote.size)
    }




    @Test
    fun testSearchByFullCharacter(){
        val quote = services.search("personnage","Arwen",1)
        assertEquals("Arwen",quote[0].character)
    }

    @Test
    fun testSearchByHalfCharacter(){
        val quote = services.search("personnage","Arw",1)
        assertEquals("Arwen",quote[0].character)
    }

    @Test
    fun testSearchByFullCharacterWithUpperCase(){
        val quote = services.search("personnage","ArwEn",1)
        assertEquals("Arwen",quote[0].character)
    }

    @Test
    fun testSearchByHalfCharacterWithUpperCase(){
        val quote = services.search("personnage","Arw",1)
        assertEquals("Arwen",quote[0].character)
    }

    @Test
    fun testSearchByFullCharacterBad(){
        val quote = services.search("personnage","Arwen bad",1)
        assertEquals(0,quote.size)
    }


    @Test
    fun testSearchByFullTitle(){
        val quote = services.search("titre","Star Wars",1)
        assertEquals("Star Wars",quote[0].source)
    }

    @Test
    fun testSearchByHalfTitle(){
        val quote = services.search("titre","Star",1)
        assertEquals("Star Wars",quote[0].source)
    }

    @Test
    fun testSearchByFullTitleWithUpperCase(){
        val quote = services.search("titre","StAr WaRs",1)
        assertEquals("Star Wars",quote[0].source)
    }

    @Test
    fun testSearchByHalfTitleWithUpperCase(){
        val quote = services.search("titre","StAr",1)
        assertEquals("Star Wars",quote[0].source)
    }

    @Test
    fun testSearchByTitleBad(){
        val quote = services.search("titre","Star Wars bad",1)
        assertEquals(0,quote.size)
    }


}